# PyRAL
A pythonic interface to Andrew Mangogna's TclRAL relational algebra tcl implementation of Date and Darwen's Tutorial D

I am just getting this started to support my SM Metamodel facilities in progress.
